@@ -1,13 +1,13 @@
 package Perinci::Access::Schemeless;
 
-our $DATE = '2015-03-06'; # DATE
-our $VERSION = '0.82'; # VERSION
+our $DATE = '2015-08-18'; # DATE
+our $VERSION = '0.83'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 use experimental 'smartmatch';
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use parent qw(Perinci::Access::Base);
 
@@ -1020,7 +1020,7 @@ Perinci::Access::Schemeless - Base class for Perinci::Access::Perl
 
 =head1 VERSION
 
-This document describes version 0.82 of Perinci::Access::Schemeless (from Perl distribution Perinci-Access-Perl), released on 2015-03-06.
+This document describes version 0.83 of Perinci::Access::Schemeless (from Perl distribution Perinci-Access-Perl), released on 2015-08-18.
 
 =head1 DESCRIPTION
 
